GWASbyGLM: Genome-wide association analysis using a general linear...

Description Usage Arguments Details Value

View source: R/GWASbyGLM.R

Description

Genome-wide association analysis using a general linear model.

Usage

1
GWASbyGLM(y, G, C, NC)

Arguments

y

A numeric matrix containing phenotype data. Dimensions are n rows (individuals) by 1 column.

G

A numeric matrix containing genotype data. Dimensions are n rows (individuals) by m columns (genetic markers).

C

A numeric matrix containing covariate data. Dimensions are n rows (individuals) by t columns (covariates). The expected input for this parameter is the $cov numeric matrix returned from the cofactor.pca.cor function included in this package.

NC

An integer specifying the number of covariates to retain for analysis.

Details

Numeric matrices should contain only phenotype/genotype/covariate values, no accessory information like taxa ID.

Type vignette("GLM2020_tutorial") for example use.

Value

A numeric matrix containing a p-value for each genetic marker. Dimensions are 1 row by m columns (genetic markers).


rachael-kane/GLM2020 documentation built on March 31, 2020, 12:51 a.m.