Description Usage Arguments Details Value
Genome-wide association analysis using a general linear model.
1 |
y |
A numeric matrix containing phenotype data. Dimensions are n rows (individuals) by 1 column. |
G |
A numeric matrix containing genotype data. Dimensions are n rows (individuals) by m columns (genetic markers). |
C |
A numeric matrix containing covariate data. Dimensions are n rows (individuals) by t columns (covariates). The expected input for this parameter is the $cov numeric matrix returned from the cofactor.pca.cor function included in this package. |
NC |
An integer specifying the number of covariates to retain for analysis. |
Numeric matrices should contain only phenotype/genotype/covariate values, no accessory information like taxa ID.
Type vignette("GLM2020_tutorial") for example use.
A numeric matrix containing a p-value for each genetic marker. Dimensions are 1 row by m columns (genetic markers).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.